@@ -2,7 +2,7 @@ package App::cpm::Worker::Installer;
 use strict;
 use warnings;
 use utf8;
-our $VERSION = '0.290';
+our $VERSION = '0.291';
 
 use App::cpm::Logger::File;
 use App::cpm::Worker::Installer::Menlo;
@@ -60,14 +60,15 @@ sub work {
 
 sub new {
     my ($class, %option) = @_;
-    my $base = $option{base} || "$ENV{HOME}/.perl-cpm/work";
     my $logger = $option{logger};
     if (!$logger) {
         (undef, my $file) = File::Temp::tempfile(UNLINK => 1);
         $logger = App::cpm::Logger::File->new($file);
     }
-    my $cache = $option{cache} || "$base/.perl-cpm/cache";
-    mkpath $base unless -d $base;
+
+    my $base  = $option{base}  || "$ENV{HOME}/.perl-cpm/work";
+    my $cache = $option{cache} || "$ENV{HOME}/.perl-cpm/cache";
+    mkpath $base for grep { !-d } $base, $cache;
 
     my $menlo = App::cpm::Worker::Installer::Menlo->new(
         base => $base,
